from ...util import registry


@registry.keyboards("da_qwerty_v1")
def create_qwerty_da():
    qwerty_da = {
        "default": [
            ["1", "2", "3", "4", "5", "6", "7", "8", "9", "0", "+", "´"],
            ["q", "w", "e", "r", "t", "y", "u", "i", "o", "p", "å", "¨"],
            ["a", "s", "d", "f", "g", "h", "j", "k", "l", "æ", "ø", "'"],
            ["<", "z", "x", "c", "v", "b", "n", "m", ",", ".", "-"],
        ],
        "shift": [
            ["!", '"', "#", "€", "%", "&", "/", "(", ")", "=", "?", "`"],
            ["Q", "W", "E", "R", "T", "Y", "U", "I", "O", "P", "Å", "^"],
            ["A", "S", "D", "F", "G", "H", "J", "K", "L", "Æ", "Ø", "*"],
            [">", "Z", "X", "C", "V", "B", "N", "M", ";", ":", "_"],
        ],
    }
    return qwerty_da
